@@ -15,7 +15,7 @@
 # $Date: 2018-03-02 12:29:05 +0800 (Fri, 02 Mar 2018) $
 # $Revision: 10806 $
 
-from django.shortcuts import render_to_response, get_object_or_404
+from django.shortcuts import render_to_response, get_object_or_404, render
 from django.contrib.auth.decorators import login_required
 from django.template import RequestContext
 from django.utils.translation import ugettext_lazy as _
@@ -33,5 +33,4 @@ def viewNewsletterHistoric(request, slug):
                'opts': opts,
                'object_id': newsletter.pk,
                'app_label': opts.app_label}
-    return render_to_response('NewsletterHistoric.html',
-                              context, context_instance=RequestContext(request))
+    return render(request, 'NewsletterHistoric.html', context)
